==> overview_field-8.x-1.0.tar.gz: overview_field/src/Plugin/Field/FieldFormatter/OverviewFieldFormatter.php <==
<?php

namespace Drupal\overview_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'overview_field_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "overview_field_formatter",
 *   label = @Translation("Overview field formatter"),
 *   field_types = {
 *     "overview_field"
 *   }
 * )
 */
class OverviewFieldFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
        // Implement default settings.
      ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [
        // Implement settings form.
      ] + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    // Implement settings summary.
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->viewValue($item);
    }

    return $elements;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return array
   *   Render array.
   */
  protected function viewValue(FieldItemInterface $item) {
    $output = [];
    \Drupal::moduleHandler()->alter('overview_field_output', $item->value, $output);
    return $output;
  }

}

==> overview_field-8.x-1.1.tar.gz: overview_field/src/Plugin/Field/FieldFormatter/OverviewFieldFormatter.php <==
<?php

namespace Drupal\overview_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'overview_field_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "overview_field_formatter",
 *   label = @Translation("Overview field formatter"),
 *   field_types = {
 *     "overview_field"
 *   }
 * )
 */
class OverviewFieldFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
        // Implement default settings.
      ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [
        // Implement settings form.
      ] + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    // Implement settings summary.
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->viewValue($item);
    }

    return $elements;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return array
   *   Render array.
   */
  protected function viewValue(FieldItemInterface $item) {
    $output = [];
    $value = $item->getValue();
    \Drupal::moduleHandler()->alter('overview_field_output', $value['value'], $output);
    return $output;
  }

}
